import { APIClient } from '@ffflorian/api-client';
import { ClientOptions, PaginationOptions, Project, RepositoryWithDependencies } from '../../interfaces/';
import { APIBase } from '../APIBase';
export declare class GitHubRepositoryAPI extends APIBase {
    constructor(apiClient: APIClient, options: ClientOptions);
    /**
     * Get a info for a repository. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepository(repositoryOwner: string, repositoryName: string): Promise<RepositoryWithDependencies>;
    /**
     * Get a list of dependencies for a repositories. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository-dependencies
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepositoryWithDependencies(repositoryOwner: string, repositoryName: string): Promise<RepositoryWithDependencies>;
    /**
     * Get a list of packages referencing the given repository.
     * @see https://libraries.io/api#repository-projects
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     * @param options Pagination Options
     */
    getProjects(repositoryOwner: string, repositoryName: string, options?: PaginationOptions): Promise<Project[]>;
}
