"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var Endpoints_1 = require("../Endpoints");
var APIBase_1 = require("./APIBase");
var ProjectAPI = /** @class */ (function (_super) {
    __extends(ProjectAPI, _super);
    function ProjectAPI(apiClient, options) {
        return _super.call(this, apiClient, options) || this;
    }
    /**
     * Get information about a package and it's versions.
     * @see https://libraries.io/api#project
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    ProjectAPI.prototype.getProject = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.Project.project(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    };
    /**
     * Get a list of dependencies for a version of a project, pass `latest` as version to get dependency info for the latest available version
     * @see https://libraries.io/api#project-dependencies
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param projectVersion
     */
    ProjectAPI.prototype.getProjectWithDependencies = function (platform, projectName, projectVersion) {
        var endpoint = Endpoints_1.Endpoint.Project.dependencies(platform, projectName, projectVersion);
        return this.apiClient.requestService.get(endpoint);
    };
    /**
     * Get packages that have at least one version that depends on a given project.
     * @see https://libraries.io/api#project-dependents
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    ProjectAPI.prototype.getDependendents = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    };
    /**
     * Get repositories that depend on a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    ProjectAPI.prototype.getDependendentRepositories = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    };
    /**
     * Get users that have contributed to a given project.
     * @see https://libraries.io/api#project-contributors
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    ProjectAPI.prototype.getContributors = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    };
    /**
     * Get breakdown of SourceRank score for a given project.
     * @see https://libraries.io/api#project-sourcerank
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    ProjectAPI.prototype.getSourceRank = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.Project.sourceRank(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    };
    /**
     * Get breakdown of version usage for a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    ProjectAPI.prototype.getUsage = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.Project.sourceRank(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    };
    /**
     * Search for projects.
     * @see https://libraries.io/api#project-search
     * @param query The search query
     * @param options Sorting, filter and pagination options
     */
    ProjectAPI.prototype.search = function (query, options) {
        var endpoint = Endpoints_1.Endpoint.Project.search();
        return this.apiClient.requestService.get(endpoint, { data: __assign({}, options, { q: query }) });
    };
    return ProjectAPI;
}(APIBase_1.APIBase));
exports.ProjectAPI = ProjectAPI;
//# sourceMappingURL=ProjectAPI.js.map