import { APIClient } from '@ffflorian/api-client';
import { ClientOptions, LibrariesIOHeaders, PaginationOptions, PlatformType, PreReleaseOptions, Subscription } from '../interfaces/';
import { APIBase } from './APIBase';
export declare class UserAPI extends APIBase {
    constructor(apiClient: APIClient, options: ClientOptions);
    /**
     * Check if a users is subscribed to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-show
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getSubscription(platform: PlatformType, projectName: string): Promise<Subscription | null>;
    /**
     * List packages that a user is subscribed to recieved notifications about new releases.
     * @see https://libraries.io/api#subscriptions-index
     * @param options Pagination options
     */
    getAllSubscriptions(options?: PaginationOptions): Promise<Subscription[]>;
    /**
     * Subscribe to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-create
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    subscribe(platform: PlatformType, projectName: string, options?: PreReleaseOptions): Promise<Subscription>;
    /**
     * Stop receiving release notifications from a project.
     * @see https://libraries.io/api#subscriptions-destroy
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    unsubscribe(platform: PlatformType, projectName: string): Promise<LibrariesIOHeaders>;
    /**
     * Update the options for a subscription.
     * @see https://libraries.io/api#subscriptions-update
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    updateSubscription(platform: PlatformType, projectName: string, options?: PreReleaseOptions): Promise<Subscription>;
}
