"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var Endpoints_1 = require("../Endpoints");
var APIBase_1 = require("./APIBase");
var UserAPI = /** @class */ (function (_super) {
    __extends(UserAPI, _super);
    function UserAPI(apiClient, options) {
        return _super.call(this, apiClient, options) || this;
    }
    /**
     * Check if a users is subscribed to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-show
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    UserAPI.prototype.getSubscription = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    };
    /**
     * List packages that a user is subscribed to recieved notifications about new releases.
     * @see https://libraries.io/api#subscriptions-index
     * @param options Pagination options
     */
    UserAPI.prototype.getAllSubscriptions = function (options) {
        var endpoint = Endpoints_1.Endpoint.subscriptions();
        return this.apiClient.requestService.get(endpoint, { data: options });
    };
    /**
     * Subscribe to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-create
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    UserAPI.prototype.subscribe = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.apiClient.requestService.post(endpoint, { data: options });
    };
    /**
     * Stop receiving release notifications from a project.
     * @see https://libraries.io/api#subscriptions-destroy
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    UserAPI.prototype.unsubscribe = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.apiClient.requestService.delete(endpoint);
    };
    /**
     * Update the options for a subscription.
     * @see https://libraries.io/api#subscriptions-update
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    UserAPI.prototype.updateSubscription = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.apiClient.requestService.put(endpoint, { data: options });
    };
    return UserAPI;
}(APIBase_1.APIBase));
exports.UserAPI = UserAPI;
//# sourceMappingURL=UserAPI.js.map